@@ -51,9 +51,6 @@ import Network.Wai.Handler.Warp.Imports hiding (readInt)
 import Network.Wai.Handler.Warp.SendFile
 import Network.Wai.Handler.Warp.Settings
 import Network.Wai.Handler.Warp.Types
-#if WINDOWS
-import Network.Wai.Handler.Warp.Windows
-#endif
 
 -- | Creating 'Connection' for plain HTTP based on a given socket.
 socketConnection :: Settings -> Socket -> IO Connection
@@ -223,7 +220,9 @@ runSettingsConnectionMakerSecure
     :: Settings -> IO (IO (Connection, Transport), SockAddr) -> Application -> IO ()
 runSettingsConnectionMakerSecure set getConnMaker app = do
     settingsBeforeMainLoop set
-    counter <- newCounter
+    counter <- case settingsConnectionCounter set of
+        Just c -> pure c
+        Nothing -> newCounter
     withII set $ acceptConnection set getConnMaker app counter
 
 -- | Running an action with internal info.
@@ -233,19 +232,19 @@ withII :: Settings -> (InternalInfo -> IO a) -> IO a
 withII set action =
     withTimeoutManager $ \tm ->
         D.withDateCache $ \dc ->
-            F.withFdCache fdCacheDurationInSeconds $ \fdc ->
-                I.withFileInfoCache fdFileInfoDurationInSeconds $ \fic -> do
+            F.withFdCache fdCacheDurationInMicroseconds $ \fdc ->
+                I.withFileInfoCache fdFileInfoDurationInMicroseconds $ \fic -> do
                     let ii = InternalInfo tm dc fdc fic
                     action ii
   where
-    !fdCacheDurationInSeconds = settingsFdCacheDuration set * 1000000
-    !fdFileInfoDurationInSeconds = settingsFileInfoCacheDuration set * 1000000
-    !timeoutInSeconds = settingsTimeout set * 1000000
+    !fdCacheDurationInMicroseconds = settingsFdCacheDuration set * 1000000
+    !fdFileInfoDurationInMicroseconds = settingsFileInfoCacheDuration set * 1000000
+    !timeoutInMicroseconds = settingsTimeout set * 1000000
     withTimeoutManager f = case settingsManager set of
         Just tm -> f tm
         Nothing ->
             E.bracket
-                (T.initialize timeoutInSeconds)
+                (T.initialize timeoutInMicroseconds)
                 T.stopManager
                 f
 
